@@ -1,4 +1,4 @@
-from typing import Type, Union
+from typing import Optional, Type, Union
 from koil.checker.base import BaseChecker
 from koil.checker.registry import register_checker
 from koil.state import KoilState
@@ -6,20 +6,17 @@ from koil.task import KoilTask
 
 
 class JupyterKoilState(KoilState):
-    
     def __init__(self, is_terminal=False, **kwargs) -> None:
         super().__init__(**kwargs)
         self.is_terminal = is_terminal
 
     def get_task_class(self) -> Type[KoilTask]:
         return KoilTask
-        
 
 
 @register_checker()
 class JupyterChecker(BaseChecker):
-
-    def force_state(self) -> Union[None, KoilState]:
+    def force_state(self) -> Optional[KoilState]:
         """Checks if a running Qt Instance is there, if so we would like
         to run in a seperate thread
 
@@ -29,15 +26,17 @@ class JupyterChecker(BaseChecker):
 
         try:
             from IPython import get_ipython
+
             shell = get_ipython().__class__.__name__
-            if shell == 'ZMQInteractiveShell':
-                return JupyterKoilState(threaded=True)   # Jupyter notebook or qtconsole
-            elif shell == 'TerminalInteractiveShell':
-                return JupyterKoilState(threaded=True, is_terminal=True)   # Terminal running IPython
+            if shell == "ZMQInteractiveShell":
+                return JupyterKoilState(threaded=True)  # Jupyter notebook or qtconsole
+            elif shell == "TerminalInteractiveShell":
+                return JupyterKoilState(
+                    threaded=True, is_terminal=True
+                )  # Terminal running IPython
             else:
                 return None  # Other type (?)
         except NameError:
-            return None  
+            return None
         except ImportError:
             return None
-
